@@ -4,6 +4,7 @@
 from __future__ import print_function
 
 from re import escape
+from re import findall
 from re import match
 from re import search
 from json import dumps
@@ -11,14 +12,13 @@ from json import loads
 
 from Components.config import config
 
+from .compat import compat_parse_qs
 from .compat import compat_str
 from .compat import compat_Request
 from .compat import compat_urlopen
 from .compat import compat_URLError
 from .compat import SUBURI
 from .jsinterp import JSInterpreter
-from .OAuth import YT_EMBKEY
-from .OAuth import YT_KEY
 
 
 PRIORITY_VIDEO_FORMAT = ()
@@ -28,12 +28,12 @@ def create_priority_formats():
 	global PRIORITY_VIDEO_FORMAT
 	itag = config.plugins.YouTube.maxResolution.value
 	video_formats = (
-		('17', '91', '13', '151', '160'),  # 176x144
-		('5', '36', '92', '132', '133'),  # 400x240
-		('18', '93', '34', '6', '134'),  # 640x360
-		('35', '59', '78', '94', '135', '212'),  # 854x480
-		('22', '95', '300', '136', '298'),  # 1280x720
-		('37', '96', '301', '137', '299', '248', '303', '271'),  # 1920x1080
+		('17', '91', '13', '151', '160', '269'),  # 176x144
+		('5', '36', '92', '132', '133', '229'),  # 400x240
+		('18', '93', '34', '6', '134', '230'),  # 640x360
+		('35', '59', '78', '94', '135', '212', '231'),  # 854x480
+		('22', '95', '300', '136', '298', '232'),  # 1280x720
+		('37', '96', '301', '137', '299', '248', '303', '271', '270'),  # 1920x1080
 		('38', '266', '264', '138', '313', '315', '272', '308')  # 4096x3072
 	)
 	for video_format in video_formats:
@@ -133,25 +133,26 @@ class YouTubeVideoUrl():
 				'https://www.youtube.com/s/player/%s/player_ias.vflset/en_US/base.js' % player_id
 			)
 
-	def _extract_n_function(self, player_id):
+	def _extract_function(self, player_id, s_id):
 		if player_id not in self._player_cache:
 			self._load_player(player_id)
 		jsi = JSInterpreter(self._player_cache[player_id])
-		if player_id not in self._code_cache:
-			funcname = self._extract_n_function_name(self._player_cache[player_id])
-			self._code_cache[player_id] = jsi.extract_function_code(funcname)
-		return lambda s: jsi.extract_function_from_code(*self._code_cache[player_id])([s])
+		if s_id not in self._code_cache:
+			if s_id.startswith('nsig_'):
+				funcname = self._extract_n_function_name(self._player_cache[player_id])
+			else:
+				funcname = self._parse_sig_js(self._player_cache[player_id])
+			self._code_cache[s_id] = jsi.extract_function_code(funcname)
+		return lambda s: jsi.extract_function_from_code(*self._code_cache[s_id])([s])
 
 	def _unthrottle_url(self, url, player_id):
-		print('[YouTubeVideoUrl] Try unthrottle url')
-		if not player_id:
-			print('[YouTubeVideoUrl] Cannot decrypt nsig without player info')
-			return url
 		n_param = search(r'&n=(.+?)&', url).group(1)
+		n_id = 'nsig_%s_%s' % (player_id, '.'.join(str(len(p)) for p in n_param.split('.')))
+		print('[YouTubeVideoUrl] Decrypt nsig', n_id)
 		if self.nsig_cache[0] != n_param:
 			self.nsig_cache = (None, None)
 			try:
-				ret = self._extract_n_function(player_id)(n_param)
+				ret = self._extract_function(player_id, n_id)(n_param)
 			except Exception as ex:
 				print('[YouTubeVideoUrl] Unable to decode nsig', ex)
 			else:
@@ -162,24 +163,78 @@ class YouTubeVideoUrl():
 		if self.nsig_cache[1]:
 			print('[YouTubeVideoUrl] Decrypted nsig %s => %s' % self.nsig_cache)
 			return url.replace(self.nsig_cache[0], self.nsig_cache[1])
-		if player_id in self._code_cache:
-			del self._code_cache[player_id]
+		if n_id in self._code_cache:
+			del self._code_cache[n_id]
 		return url
 
+	def _decrypt_signature(self, s, player_id):
+		"""Turn the encrypted s field into a working signature"""
+		s_id = 'sig_%s_%s' % (player_id, '.'.join(str(len(p)) for p in s.split('.')))
+		print('[YouTubeVideoUrl] Decrypt signature', s_id)
+		try:
+			return self._extract_function(player_id, s_id)(s)
+		except Exception as ex:
+			print('[YouTubeVideoUrl] Signature extraction failed', ex)
+			if s_id in self._code_cache:
+				del self._code_cache[s_id]
+
+	def _parse_sig_js(self, jscode):
+
+		def _search_regex(pattern, string):
+			mobj = ''
+			for p in pattern:
+				mobj = search(p, string, 0)
+				if mobj:
+					break
+			return mobj
+
+		return _search_regex(
+			(r'\b[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*encodeURIComponent\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\b[a-zA-Z0-9]+\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*encodeURIComponent\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\bm=(?P<sig>[a-zA-Z0-9$]{2,})\(decodeURIComponent\(h\.s\)\)',
+				r'\bc&&\(c=(?P<sig>[a-zA-Z0-9$]{2,})\(decodeURIComponent\(c\)\)',
+				r'(?:\b|[^a-zA-Z0-9$])(?P<sig>[a-zA-Z0-9$]{2,})\s*=\s*function\(\s*a\s*\)\s*{\s*a\s*=\s*a\.split\(\s*""\s*\)(?:;[a-zA-Z0-9$]{2}\.[a-zA-Z0-9$]{2}\(a,\d+\))?',
+				r'(?P<sig>[a-zA-Z0-9$]+)\s*=\s*function\(\s*a\s*\)\s*{\s*a\s*=\s*a\.split\(\s*""\s*\)',
+				# Obsolete patterns
+				r'("|\')signature\1\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\.sig\|\|(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'yt\.akamaized\.net/\)\s*\|\|\s*.*?\s*[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*(?:encodeURIComponent\s*\()?\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\b[cs]\s*&&\s*[adf]\.set\([^,]+\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\b[a-zA-Z0-9]+\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*(?P<sig>[a-zA-Z0-9$]+)\(',
+				r'\bc\s*&&\s*[a-zA-Z0-9]+\.set\([^,]+\s*,\s*\([^)]*\)\s*\(\s*(?P<sig>[a-zA-Z0-9$]+)\('),
+			jscode
+		).group('sig')
+
+	@staticmethod
+	def _parse_m3u8_attributes(attrib):
+		return {key: val[1:-1] if val.startswith('"') else val for (key, val) in findall(r'(?P<key>[A-Z0-9-]+)=(?P<val>"[^"]+"|[^",]+)(?:,|$)', attrib)}
+
+	def _get_m3u8_audio_urls(self, manifest):
+		audio_urls = {}
+		if '#EXT-X-MEDIA:' in manifest:
+			for line in manifest.splitlines():
+				if line.startswith('#EXT-X-MEDIA:'):
+					audio_info = self._parse_m3u8_attributes(line)
+					audio_urls[audio_info.get('GROUP-ID')] = audio_info.get('URI')
+		return audio_urls
+
 	def _extract_from_m3u8(self, manifest_url):
 		url_map = {}
-
-		def _get_urls(_manifest):
-			lines = _manifest.split('\n')
-			urls = [x for x in lines if x and not x.startswith('#')]
-			return urls
+		audio_url = ''
 
 		manifest = self._download_webpage(manifest_url)
-		formats_urls = _get_urls(manifest)
-		for format_url in formats_urls:
-			itag = search(r'itag/(\d+?)/', format_url)
-			itag = itag.group(1) if itag else ''
-			url_map[itag] = format_url
+		audio_urls = self._get_m3u8_audio_urls(manifest)
+
+		for line in manifest.splitlines():
+			if audio_urls and line.startswith('#EXT-X-STREAM-INF:'):
+				audio_id = self._parse_m3u8_attributes(line).get('AUDIO')
+				if audio_id and audio_id in audio_urls:
+					audio_url = SUBURI + audio_urls.get(audio_id)
+			elif line.startswith('https'):
+				itag = search(r'/sgovp/[^/]+itag%3D(\d+?)/', line) or search(r'/itag/(\d+?)/', line)
+				if itag:
+					url_map[itag.group(1)] = line + audio_url
+					audio_url = ''
 		return url_map
 
 	def _not_in_fmt(self, fmt, itag):
@@ -190,36 +245,56 @@ class YouTubeVideoUrl():
 			itag in self.use_dash_mp4
 		)
 
-	def _extract_fmt_video_format(self, streaming_formats):
+	def _extract_url(self, our_format, streaming_formats, player_id):
+		for fmt in streaming_formats:
+			itag = str(fmt.get('itag', ''))
+			if itag == our_format and self._not_in_fmt(fmt, itag):
+				url = fmt.get('url')
+				if not url and 'signatureCipher' in fmt:
+					sc = compat_parse_qs(fmt.get('signatureCipher', ''))
+					sig = self._decrypt_signature(sc['s'][0], player_id)
+					if sig:
+						url = '%s&%s=%s' % (sc['url'][0], sc['sp'][0] if 'sp' in sc else 'signature', sig)
+				if url:
+					if '&n=' in url:
+						url = self._unthrottle_url(url, player_id)
+					return url
+
+	def _extract_fmt_video_format(self, streaming_formats, player_id):
 		""" Find the best format from our format priority map """
 		print('[YouTubeVideoUrl] Try fmt url')
 		for our_format in PRIORITY_VIDEO_FORMAT:
-			for fmt in streaming_formats:
-				itag = str(fmt.get('itag', ''))
-				if itag == our_format and self._not_in_fmt(fmt, itag):
-					url = fmt.get('url')
-					if url:
-						print('[YouTubeVideoUrl] Found fmt url')
-						return url, our_format
+			url = self._extract_url(our_format, streaming_formats, player_id)
+			if url:
+				print('[YouTubeVideoUrl] Found fmt url')
+				return url, our_format
 		return '', ''
 
-	def _extract_dash_audio_format(self, streaming_formats):
+	def _extract_dash_audio_format(self, streaming_formats, player_id):
 		""" If DASH MP4 video add link also on Dash MP4 Audio """
 		print('[YouTubeVideoUrl] Try fmt audio url')
-		for our_format in ('141', '140', '139', '258', '265', '325', '328'):
-			for fmt in streaming_formats:
-				itag = str(fmt.get('itag', ''))
-				if itag == our_format and self._not_in_fmt(fmt, itag):
-					url = fmt.get('url')
-					if url:
-						print('[YouTubeVideoUrl] Found fmt audio url')
-						return url
+		for our_format in ('141', '140', '139', '258', '265', '325', '328', '233', '234'):
+			url = self._extract_url(our_format, streaming_formats, player_id)
+			if url:
+				print('[YouTubeVideoUrl] Found fmt audio url')
+				return url
 		return ''
 
+	def _extract_web_response(self, video_id):
+		url = 'https://www.youtube.com/watch?v=%s&bpctr=9999999999&has_verified=1' % video_id
+		webpage = self._download_webpage(url)
+		if webpage:
+			player_response = search(r'ytInitialPlayerResponse\s*=\s*({[^>]*})\s*;\s*(?:var\s+meta|</script|\n)', webpage)
+			if player_response:
+				try:
+					return loads(player_response.group(1)), self._extract_player_info()
+				except ValueError:  # pragma: no cover
+					print('[YouTubeVideoUrl] Failed to parse web JSON')
+		return None, None
+
 	def _extract_player_response(self, video_id, client):
 		player_id = None
-		url = 'https://www.youtube.com/youtubei/v1/player?key=%s&bpctr=9999999999&has_verified=1' % (YT_EMBKEY if client == 85 else YT_KEY)
-		USER_AGENT = 'com.google.android.youtube/17.31.35 (Linux; U; Android 12) gzip'
+		url = 'https://www.youtube.com/youtubei/v1/player?prettyPrint=false'
 		data = {
 			'videoId': video_id,
 			'playbackContext': {
@@ -230,9 +305,24 @@ class YouTubeVideoUrl():
 		}
 		headers = {
 			'content-type': 'application/json',
-			'Origin': 'https://www.youtube.com'
+			'Origin': 'https://www.youtube.com',
+			'X-YouTube-Client-Name': client
 		}
-		if client == 85:
+		if client == 5:
+			VERSION = '19.09.3'
+			USER_AGENT = 'com.google.ios.youtube/%s (iPhone14,3; U; CPU iOS 15_6 like Mac OS X)' % VERSION
+			data['context'] = {
+				'client': {
+					'hl': config.plugins.YouTube.searchLanguage.value,
+					'clientVersion': VERSION,
+					'clientName': 'IOS',
+					'deviceModel': 'iPhone14,3',
+					'userAgent': USER_AGENT
+				}
+			}
+			headers['X-YouTube-Client-Version'] = VERSION
+			headers['User-Agent'] = USER_AGENT
+		elif client == 85:
 			player_id = self._extract_player_info()
 			if player_id:
 				if player_id not in self._player_cache:
@@ -253,23 +343,23 @@ class YouTubeVideoUrl():
 					'embedUrl': 'https://www.youtube.com/'
 				}
 			}
-			headers['X-YouTube-Client-Name'] = 85
 			headers['X-YouTube-Client-Version'] = '2.0'
 		else:
+			VERSION = '1.9'
+			USER_AGENT = 'com.google.android.youtube/%s (Linux; U; Android 12; US) gzip' % VERSION
 			data['context'] = {
 				'client': {
 					'hl': config.plugins.YouTube.searchLanguage.value,
-					'clientVersion': '17.31.35',
+					'clientVersion': VERSION,
 					'androidSdkVersion': 31,
-					'clientName': 'ANDROID',
+					'clientName': 'ANDROID_TESTSUITE',
 					'osName': 'Android',
 					'osVersion': '12',
 					'userAgent': USER_AGENT
 				}
 			}
-			data['params'] = 'CgIQBg'
-			headers['X-YouTube-Client-Name'] = 3
-			headers['X-YouTube-Client-Version'] = '17.31.35'
+			data['params'] = '2AMB'
+			headers['X-YouTube-Client-Version'] = VERSION
 			headers['User-Agent'] = USER_AGENT
 		try:
 			return loads(self._download_webpage(url, data, headers)), player_id
@@ -286,15 +376,36 @@ class YouTubeVideoUrl():
 			'170', '171', '172',  # webm
 			'218', '219',  # webm
 			'242', '243', '244', '245', '246', '247',  # webm
+			'394', '395', '396', '397', '398', '399', '400', '401', '402', '694', '695', '696', '697', '698', '699', '700', '701', '571',  # AV1
 			'249', '250', '251',  # webm
 			'302'  # webm
 		)
+		DASHMP4_FORMAT = (
+			'133', '134', '135', '136', '137', '138', '160',
+			'212', '229', '230', '231', '232', '248', '264',
+			'271', '272', '266', '269', '270', '298', '299',
+			'303', '313', '315', '308'
+		)
 		url = ''
 
-		player_response, player_id = self._extract_player_response(video_id, 3)
+		if config.plugins.YouTube.useDashMP4.value:
+			self.use_dash_mp4 = ()
+		else:
+			print('[YouTubeVideoUrl] skip DASH MP4 format')
+			self.use_dash_mp4 = DASHMP4_FORMAT
+
+		player_response, player_id = self._extract_player_response(video_id, 30)
 		if not player_response:
 			raise RuntimeError('Player response not found!')
 
+		if self.try_get(player_response, lambda x: x['videoDetails']['videoId']) != video_id:
+			if self.use_dash_mp4:
+				print('[YouTubeVideoUrl] Got wrong player response, try web response')
+				player_response, player_id = self._extract_web_response(video_id)
+			else:
+				print('[YouTubeVideoUrl] Got wrong player response, try ios client')
+				player_response, player_id = self._extract_player_response(video_id, 5)
+
 		is_live = self.try_get(player_response, lambda x: x['videoDetails']['isLive'])
 		playability_status = player_response.get('playabilityStatus', {})
 
@@ -322,28 +433,12 @@ class YouTubeVideoUrl():
 		if PRIORITY_VIDEO_FORMAT[0] != config.plugins.YouTube.maxResolution.value:
 			create_priority_formats()
 
-		if not is_live and streaming_formats:
-			DASHMP4_FORMAT = (
-				'133', '134', '135', '136', '137', '138',
-				'160', '212', '264', '266', '298', '299',
-				'248', '303', '271', '313', '315', '272', '308'
-			)
+		if not is_live:
 			streaming_formats.extend(streaming_data.get('adaptiveFormats', []))
-
-			if config.plugins.YouTube.useDashMP4.value:
-				self.use_dash_mp4 = ()
-			else:  # pragma: no cover
-				print('[YouTubeVideoUrl] skip DASH MP4 format')
-				self.use_dash_mp4 = DASHMP4_FORMAT
-
-			url, our_format = self._extract_fmt_video_format(streaming_formats)
-			if url and '&n=' in url:
-				url = self._unthrottle_url(url, player_id)
+			url, our_format = self._extract_fmt_video_format(streaming_formats, player_id)
 			if url and our_format in DASHMP4_FORMAT:
-				audio_url = self._extract_dash_audio_format(streaming_formats)
+				audio_url = self._extract_dash_audio_format(streaming_formats, player_id)
 				if audio_url:
-					if '&n=' in audio_url:
-						audio_url = self._unthrottle_url(audio_url, player_id)
 					url += SUBURI + audio_url
 			if not url:  # pragma: no cover
 				for fmt in streaming_formats:
