@@ -143,6 +143,15 @@ def unified_timestamp(date_str):
 			pass
 
 
+def remove_quotes(s):
+	if s is None or len(s) < 2:
+		return s
+	for quote in ('"', "'", ):
+		if s[0] == quote and s[-1] == quote:
+			return s[1:-1]
+	return s
+
+
 # NB In principle NaN cannot be checked by membership.
 # Here all NaN values are actually this one, so _NaN is _NaN,
 # although _NaN != _NaN.
@@ -290,6 +299,13 @@ class LocalNameSpace(compat_map):
 		except KeyError:
 			return JSUndefined
 
+	def __setitem__(self, key, value):
+		for scope in self.maps:
+			if key in scope:
+				scope[key] = value
+				return
+		self.maps[0][key] = value
+
 
 class JSInterpreter(object):
 	__named_object_counter = 0
@@ -746,6 +762,14 @@ class JSInterpreter(object):
 				obj = local_vars.get(variable)
 				if obj in (JSUndefined, None):
 					obj = types.get(variable, JSUndefined)
+				if obj is JSUndefined:
+					try:
+						if variable not in self._objects:
+							self._objects[variable] = self.extract_object(variable)
+						obj = self._objects[variable]
+					except Exception:
+						if not nullish:
+							raise
 
 				if nullish and obj is JSUndefined:
 					return JSUndefined
@@ -808,6 +832,11 @@ class JSInterpreter(object):
 						return obj.index(idx, start)
 					except ValueError:
 						return -1
+				elif member == 'charCodeAt':
+					idx = argvals[0] if isinstance(argvals[0], int) else 0
+					if idx >= len(obj):
+						return None
+					return ord(obj[idx])
 
 				idx = int(member) if isinstance(obj, list) else member
 				return obj[idx](argvals, allow_recursion=allow_recursion)
@@ -837,6 +866,34 @@ class JSInterpreter(object):
 			raise RuntimeError('Cannot return from an expression')
 		return ret
 
+	def extract_object(self, objname):
+		_FUNC_NAME_RE = r'''(?:[a-zA-Z$0-9]+|"[a-zA-Z$0-9]+"|'[a-zA-Z$0-9]+')'''
+		obj = {}
+		fields = None
+		for obj_m in re.finditer(
+			r'''(?xs)
+				{0}\s*\.\s*{1}|{1}\s*=\s*\{{\s*
+				(?P<fields>({2}\s*:\s*function\s*\(.*?\)\s*\{{.*?}}(?:,\s*)?)*)
+				}}\s*;
+			'''.format(_NAME_RE, re.escape(objname), _FUNC_NAME_RE),
+			self.code):
+			fields = obj_m.group('fields')
+			if fields:
+				break
+		else:
+			raise RuntimeError('Could not find object ' + objname)
+		# Currently, it only supports function definitions
+		fields_m = re.finditer(
+			r'''(?x)
+				(?P<key>%s)\s*:\s*function\s*\((?P<args>(?:%s|,)*)\){(?P<code>[^}]+)}
+			''' % (_FUNC_NAME_RE, _NAME_RE),
+			fields)
+		for f in fields_m:
+			argnames = self.build_arglist(f.group('args'))
+			obj[remove_quotes(f.group('key'))] = self.build_function(argnames, f.group('code'))
+
+		return obj
+
 	@staticmethod
 	def _offset_e_by_d(d, e, local_vars):
 		""" Short-cut eval: (d%e.length+e.length)%e.length """
