@@ -27,6 +27,7 @@ class Screen(dict):
 		self.onExecBegin = []
 		self.onExecEnd = []
 		self.onLayoutFinish = []
+		self.onContentChanged = []
 		self.onShown = []
 		self.onShow = []
 		self.onHide = []
@@ -201,8 +202,7 @@ class Screen(dict):
 		self.desktop = desktop
 
 	def setAnimationMode(self, mode):
-		if self.instance:
-			self.instance.setAnimationMode(mode)
+		pass
 
 	def getRelatedScreen(self, name):
 		if name == "session":
@@ -218,6 +218,13 @@ class Screen(dict):
 		self.__callLaterTimer.callback.append(function)
 		self.__callLaterTimer.start(0, True)
 
+	def screenContentChanged(self):
+		for f in self.onContentChanged:
+			if not isinstance(f, type(self.close)):
+				exec(f, globals(), locals())  # Python 3
+			else:
+				f()
+
 	def applySkin(self):
 		# DEBUG: baseRes = (getDesktop(GUI_SKIN_ID).size().width(), getDesktop(GUI_SKIN_ID).size().height())
 		baseRes = (720, 576)  # FIXME: A skin might have set another resolution, which should be the base res.
@@ -304,5 +311,8 @@ class ScreenSummary(Screen):
 		if not isinstance(names, list):
 			names = [names]
 		self.skinName = ["%sSummary" % x for x in names]
+		className = self.__class__.__name__
+		if className != "ScreenSummary" and className not in self.skinName:  # e.g. if a module uses Screens.Setup.SetupSummary the skin needs to be available directly
+			self.skinName.append(className)
 		self.skinName.append("ScreenSummary")
 		self.skin = parent.__dict__.get("skinSummary", self.skin)  # If parent has a "skinSummary" defined, use that as default.
