@@ -130,7 +130,7 @@ class ServiceInfo(Screen):
 
 	def ShowServiceInformation(self):
 		if self.type == TYPE_SERVICE_INFO:
-			self["Title"].text = _("Service info - service & PIDs")
+			self.setTitle(_("Service info - service & PIDs"))
 			if self.feinfo or self.transponder_info:
 				self["key_blue"].text = self["blue"].text = _("Tuner setting values")
 			if self.session.nav.getCurrentlyPlayingServiceOrGroup():
@@ -239,11 +239,11 @@ class ServiceInfo(Screen):
 			if self.show_all is True:
 				self.show_all = False
 				self["key_yellow"].text = self["yellow"].text = _("Extended info") if self.IPTV else _("Extended PID info")
-				self["Title"].text = _("Service info - service & Basic PID Info")
+				self.setTitle(_("Service info - service & Basic PID Info"))
 			else:
 				self.show_all = True
 				self["key_yellow"].text = self["yellow"].text = _("Basic info") if self.IPTV else _("Basic PID info")
-				self["Title"].text = _("Service info - service & Extended PID Info")
+				self.setTitle(_("Service info - service & Extended PID Info"))
 		else:
 			self.show_all = False
 
@@ -285,15 +285,15 @@ class ServiceInfo(Screen):
 			frontendData = self.feinfo and self.feinfo.getAll(True)
 			if frontendData:
 				if self["key_blue"].text == _("Tuner setting values"):
-					self["Title"].text = _("Service info - tuner setting values")
+					self.setTitle(_("Service info - tuner setting values"))
 					self["key_blue"].text = self["blue"].text = _("Tuner live values")
 				else:
-					self["Title"].text = _("Service info - tuner live values")
+					self.setTitle(_("Service info - tuner live values"))
 					self["key_blue"].text = self["blue"].text = _("Tuner setting values")
 					frontendData = self.feinfo.getAll(False)
 				self.fillList(self.getFEData(frontendData))
 			elif self.transponder_info:
-				self["Title"].text = _("Service info - tuner setting values")
+				self.setTitle(_("Service info - tuner setting values"))
 				self["key_blue"].text = self["blue"].text = _("Tuner setting values")
 				self.fillList(self.getFEData(self.transponder_info))
 
@@ -368,7 +368,7 @@ class ServiceInfo(Screen):
 		if self.info and not self.IPTV:
 			self.show_all = True
 			from Components.Converter.PliExtraInfo import caid_data
-			self["Title"].text = _("Service info - ECM Info")
+			self.setTitle(_("Service info - ECM Info"))
 			self["key_yellow"].text = self["yellow"].text = _("Service & PIDs")
 			tlist = []
 			for caid in sorted(set(self.info.getInfoObject(iServiceInformation.sCAIDPIDs)), key=lambda x: (x[0], x[1])):
